@@ -91,7 +91,7 @@ void TransferHistoryItemDelegate::paint(QPainter *painter,
     QUrl url(model->data(index, TransferHistoryCategorizedDelegate::RoleUrl).toString());
     QString name = url.path().mid(url.path().lastIndexOf("/") + 1);
     QIcon icon(KIO::pixmapForUrl(
-                    model->data(index, TransferHistoryCategorizedDelegate::RoleDest).toUrl(),
+                    QUrl::fromLocalFile(model->data(index, TransferHistoryCategorizedDelegate::RoleDest).toString()),
                     0, KIconLoader::Panel));
     QString size = KIO::convertSize(model->data(index, TransferHistoryCategorizedDelegate::RoleSize).toInt());
     QString date = model->data(index, TransferHistoryCategorizedDelegate::RoleDate).toDate().toString("dd.MM.yyyy");
